@@ -3,7 +3,7 @@ import numpy as np
 
 class GeneSetScore(dict):
 
-    def __init__(self, matrix, geneNamesList, epsilon=10**-6):
+    def __init__(self, geneID, matrix, geneNamesList, epsilon=10**-6):
 
         self.epsilon = epsilon
 
@@ -34,6 +34,7 @@ class GeneSetScore(dict):
         # can have an effect to the score.
 
         for col in range(num_cols):
+
             i, j = np.nonzero(matrix[:, col])[0]
             # Get nonzero rows as i,j
 
