@@ -1,10 +1,10 @@
 from ..GeneSets.geneSetObjects import getGSNA
 from ..GeneSets.geneSetScores import GeneSetScore
 
-from ..GeneExpressions.geneExpScores import score
+from ..GeneExpressions.geneExpScores import expScore
 
 import numpy as np
-
+from pandas import DataFrame
 from anndata import AnnData
 
 
@@ -25,17 +25,19 @@ def runGSNA(adata, jsonFile, normalized=False):
 
         _geneNames = geneset.getGeneNames
 
-        newGeneSetScore = GeneSetScore(geneset.matrix, _geneNames)
+        newGeneSetScore = GeneSetScore(geneset.getID,geneset.matrix, _geneNames)
 
-        newExpScore = score(adata, newGeneSetScore)
+        newExpScore = expScore(adata, newGeneSetScore)
 
         scoresArray.append(newExpScore)
 
     scoresArray = np.array(scoresArray).T
 
+    geneSetNamesArray = DataFrame(geneSetNamesArray)
+
     adataScores = AnnData(X=scoresArray, var=geneSetNamesArray,
                           obs=adata.obs)
-
+    print(adataScores.var)
     if normalized:
         # If the normalized option is on, normalize the score data with
         # Quantile normalization and Z-Score normalization.
